/*
 * Licensed to Elastic Search and Shay Banon under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. Elastic Search licenses this
 * file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.action.admin.indices.gateway.snapshot;

import org.elasticsearch.action.support.replication.IndicesReplicationOperationRequest;
import org.elasticsearch.util.TimeValue;

/**
 * Gateway snapshot allows to explicitly perform a snapshot through the gateway of one or more indices (backup them).
 * By default, each index gateway periodically snapshot changes, though it can be disabled and be controlled completely
 * through this API. Best created using {@link org.elasticsearch.client.Requests#gatewaySnapshotRequest(String...)}.
 *
 * @author kimchy (shay.banon)
 * @see org.elasticsearch.client.Requests#gatewaySnapshotRequest(String...)
 * @see org.elasticsearch.client.IndicesAdminClient#gatewaySnapshot(GatewaySnapshotRequest)
 * @see GatewaySnapshotResponse
 */
public class GatewaySnapshotRequest extends IndicesReplicationOperationRequest {

    GatewaySnapshotRequest() {

    }

    /**
     * Constructs a new gateway snapshot against one or more indices. No indices means the gateway snapshot
     * will be executed against all indices.
     */
    public GatewaySnapshotRequest(String... indices) {
        this.indices = indices;
    }

    /**
     * Should the listener be called on a separate thread if needed.
     */
    @Override public GatewaySnapshotRequest listenerThreaded(boolean threadedListener) {
        super.listenerThreaded(threadedListener);
        return this;
    }

    public GatewaySnapshotRequest timeout(TimeValue timeout) {
        this.timeout = timeout;
        return this;
    }
}